Learn R Programming

asus (version 1.5.0)

sureshrink: SureShrink estimator

Description

SureShrink estimator of a high dimensional sparse parameter from Donoho and Johnstone (1995)

Usage

sureshrink(d, v.d)

Value

  1. est - an n vector holding the estimates

  2. t - estimated threshold

Arguments

d

an n vector of observations

v.d

an n vector of variances for each component of d

Details

Estimates a threshold t by minimizing the SURE function and then soft thresholds d using t.

References

David L Donoho and Iain M Johnstone. Adapting to unknown smoothness via wavelet shrinkage. Journal of the american statistical association, 90(432):1200-1224, 1995

See Also

sureshrink.mse

Examples

Run this code
library(asus)
set.seed(42)
d<-rnorm(10,2,1)
v.d<- rep(1,10)
theta.hat<-sureshrink(d,v.d)

Run the code above in your browser using DataLab